## Turbinia local stack using Docker
Turbinia can be run locally without any Cloud components using Docker. It will use Redis, Celery and local disk to store data and perform message broker functionality.

Detailed documentation and setup steps are available [here](https://turbinia.readthedocs.io/en/latest/user/turbinia-local-stack.html).
